/*
Copyright © 2025 Jake jake.young.dev@gmail.com
*/
package cmd

import (
	"errors"
	"fmt"

	"github.com/spf13/cobra"
	"github.com/spf13/viper"
)

// viewCmd represents the view command
var viewCmd = &cobra.Command{
	Use:     "view <name>",
	Example: "mctl view test",
	Short:   "View saved commands",
	Long:    `Load command using the supplied name and displays it in the terminal`,
	Run: func(cmd *cobra.Command, args []string) {
		var cm map[string]any
		cmdMap := viper.Get("customcmd")
		if cmdMap == nil {
			fmt.Println("no custom commands found")
			return
		}

		cm = cmdMap.(map[string]any)
		custom, ok := cm[args[0]]
		if !ok {
			fmt.Println("command not found")
			return
		}

		fmt.Printf("Command: %s", custom.(string))
	},
	PreRunE: func(cmd *cobra.Command, args []string) error {
		if len(args) == 0 {
			return errors.New("name argument is required")
		}

		return nil
	},
}

func init() {
	rootCmd.AddCommand(viewCmd)
}
